==> swipl-9.3.9.tar.gz: swipl-9.3.9/packages/xpce/config.h.cmake <==
#cmakedefine PCE_OS "@PCE_OS@"
#cmakedefine PCE_MACHINE "@PCE_MACHINE@"
#cmakedefine PCE_VERSION "@PCE_VERSION@"
#cmakedefine HAVE_ALLOCA @HAVE_ALLOCA@
#cmakedefine HAVE_ALLOCA_H @HAVE_ALLOCA_H@
#cmakedefine HAVE_ATEXIT @HAVE_ATEXIT@
#cmakedefine HAVE_BSTRING_H @HAVE_BSTRING_H@
#cmakedefine HAVE_CAST_VA_LIST @HAVE_CAST_VA_LIST@
#cmakedefine HAVE_CLOCK_GETTIME @HAVE_CLOCK_GETTIME@
#cmakedefine HAVE_CONIO_H @HAVE_CONIO_H@
#cmakedefine HAVE_CRT_EXTERNS_H @HAVE_CRT_EXTERNS_H@
#cmakedefine HAVE_DIRENT_H @HAVE_DIRENT_H@
#cmakedefine HAVE_FORK @HAVE_FORK@
#cmakedefine HAVE_FRAME_H @HAVE_FRAME_H@
#cmakedefine HAVE_FSTAT @HAVE_FSTAT@
#cmakedefine HAVE_FTIME @HAVE_FTIME@
#cmakedefine HAVE_GETCWD @HAVE_GETCWD@
#cmakedefine HAVE_GETDTABLESIZE @HAVE_GETDTABLESIZE@
#cmakedefine HAVE_GETHOSTNAME @HAVE_GETHOSTNAME@
#cmakedefine HAVE_GETLOGIN @HAVE_GETLOGIN@
#cmakedefine HAVE_GETPID @HAVE_GETPID@
#cmakedefine HAVE_GETPWNAM @HAVE_GETPWNAM@
#cmakedefine HAVE_GETTIMEOFDAY @HAVE_GETTIMEOFDAY@
#cmakedefine HAVE_GRANTPT @HAVE_GRANTPT@
#cmakedefine HAVE_INTTYPES_H @HAVE_INTTYPES_H@
#cmakedefine HAVE_JERROR_H @HAVE_JERROR_H@
#cmakedefine HAVE_LIBJPEG @HAVE_LIBJPEG@
#cmakedefine HAVE_LIBNSL @HAVE_LIBNSL@
#cmakedefine HAVE_LIBPTHREAD @HAVE_LIBPTHREAD@
#cmakedefine HAVE_LIBPTHREADGC @HAVE_LIBPTHREADGC@
#cmakedefine HAVE_LIBPTHREADGC @HAVE_LIBPTHREADGC@2
#cmakedefine HAVE_LIBSOCKET @HAVE_LIBSOCKET@
#cmakedefine HAVE_LIBXINERAMA @HAVE_LIBXINERAMA@
#cmakedefine HAVE_LIBXPM @HAVE_LIBXPM@
#cmakedefine HAVE_MALLOC_H @HAVE_MALLOC_H@
#cmakedefine HAVE_MEMMOVE @HAVE_MEMMOVE@
#cmakedefine HAVE_MEMORY_H @HAVE_MEMORY_H@
#cmakedefine HAVE_MKSTEMP @HAVE_MKSTEMP@
#cmakedefine HAVE_MKTIME @HAVE_MKTIME@
#cmakedefine HAVE_NANOSLEEP @HAVE_NANOSLEEP@
#cmakedefine HAVE_NDIR_H @HAVE_NDIR_H@
#cmakedefine HAVE_ON_EXIT @HAVE_ON_EXIT@
#cmakedefine HAVE_POLL @HAVE_POLL@
#cmakedefine HAVE_POLL_H @HAVE_POLL_H@
#cmakedefine HAVE_POPEN @HAVE_POPEN@
#cmakedefine HAVE_PWD_H @HAVE_PWD_H@
#cmakedefine HAVE_RENAME @HAVE_RENAME@
#cmakedefine HAVE_SCHED_H @HAVE_SCHED_H@
#cmakedefine HAVE_SCHED_YIELD @HAVE_SCHED_YIELD@
#cmakedefine HAVE_SELECT @HAVE_SELECT@
#cmakedefine HAVE_SETSID @HAVE_SETSID@
#cmakedefine HAVE_SHUTDOWN @HAVE_SHUTDOWN@
#cmakedefine HAVE_SIGACTION @HAVE_SIGACTION@
#cmakedefine HAVE_SIGINFO_H @HAVE_SIGINFO_H@
#cmakedefine HAVE_SOCKET @HAVE_SOCKET@
#cmakedefine HAVE_SOCKLEN_T @HAVE_SOCKLEN_T@
#cmakedefine HAVE_STDINT_H @HAVE_STDINT_H@
#cmakedefine HAVE_STDLIB_H @HAVE_STDLIB_H@
#cmakedefine HAVE_STRERROR @HAVE_STRERROR@
#cmakedefine HAVE_STRINGS_H @HAVE_STRINGS_H@
#cmakedefine HAVE_STRING_H @HAVE_STRING_H@
#cmakedefine HAVE_STROPTS_H @HAVE_STROPTS_H@
#cmakedefine HAVE_SYSINFO @HAVE_SYSINFO@
#cmakedefine HAVE_SYS_ACCESS_H @HAVE_SYS_ACCESS_H@
#cmakedefine HAVE_SYS_DIR_H @HAVE_SYS_DIR_H@
#cmakedefine HAVE_SYS_FILE_H @HAVE_SYS_FILE_H@
#cmakedefine HAVE_SYS_NDIR_H @HAVE_SYS_NDIR_H@
#cmakedefine HAVE_SYS_PARAM_H @HAVE_SYS_PARAM_H@
#cmakedefine HAVE_SYS_RESOURCE_H @HAVE_SYS_RESOURCE_H@
#cmakedefine HAVE_SYS_SELECT_H @HAVE_SYS_SELECT_H@
#cmakedefine HAVE_SYS_SOCKETVAR_H @HAVE_SYS_SOCKETVAR_H@
#cmakedefine HAVE_SYS_STAT_H @HAVE_SYS_STAT_H@
#cmakedefine HAVE_SYS_TIMEB_H @HAVE_SYS_TIMEB_H@
#cmakedefine HAVE_SYS_TIMES_H @HAVE_SYS_TIMES_H@
#cmakedefine HAVE_SYS_TIME_H @HAVE_SYS_TIME_H@
#cmakedefine HAVE_SYS_TYPES_H @HAVE_SYS_TYPES_H@
#cmakedefine HAVE_TEMPNAM @HAVE_TEMPNAM@
#cmakedefine HAVE_TERMIOS_H @HAVE_TERMIOS_H@
#cmakedefine HAVE_TERMIO_H @HAVE_TERMIO_H@
#cmakedefine HAVE_TIMEGM @HAVE_TIMEGM@
#cmakedefine HAVE_TIMELOCAL @HAVE_TIMELOCAL@
#cmakedefine HAVE_TMPNAM @HAVE_TMPNAM@
#cmakedefine HAVE_TM_GMTOFF @HAVE_TM_GMTOFF@
#cmakedefine HAVE_TTCOMPAT @HAVE_TTCOMPAT@
#cmakedefine HAVE_UNISTD_H @HAVE_UNISTD_H@
#cmakedefine HAVE_UXNT_H @HAVE_UXNT_H@
#cmakedefine HAVE_VISIBILITY_ATTRIBUTE @HAVE_VISIBILITY_ATTRIBUTE@
#cmakedefine HAVE_VSSCANF @HAVE_VSSCANF@
#cmakedefine HAVE_WINSOCK @HAVE_WINSOCK@
#cmakedefine HAVE_X @HAVE_X@11_EXTENSIONS_XINERAMA_H
#cmakedefine HAVE_X @HAVE_X@11_XPM_H
#cmakedefine HAVE_XFTNAMEUNPARSE @HAVE_XFTNAMEUNPARSE@
#cmakedefine HAVE_XINITTHREADS @HAVE_XINITTHREADS@
#cmakedefine HAVE_XMISMOTIFWMRUNNING @HAVE_XMISMOTIFWMRUNNING@
#cmakedefine HAVE_XTPOPUPSPRINGLOADED @HAVE_XTPOPUPSPRINGLOADED@
#cmakedefine HAVE__NSGETENVIRON @HAVE__NSGETENVIRON@
#cmakedefine O_DOSFILENAMES @O_DOSFILENAMES@
#cmakedefine O_HASSHARES @O_HASSHARES@
#cmakedefine O_PLMT @O_PLMT@
#cmakedefine O_XOS @O_XOS@
#cmakedefine PACKAGE_BUGREPORT @PACKAGE_BUGREPORT@
#cmakedefine PACKAGE_NAME @PACKAGE_NAME@
#cmakedefine PACKAGE_STRING @PACKAGE_STRING@
#cmakedefine PACKAGE_TARNAME @PACKAGE_TARNAME@
#cmakedefine PACKAGE_URL @PACKAGE_URL@
#cmakedefine PACKAGE_VERSION @PACKAGE_VERSION@
#cmakedefine POINTER_OFFSET @POINTER_OFFSET@
#cmakedefine RETSIGTYPE @RETSIGTYPE@
#cmakedefine SIZEOF_DOUBLE @SIZEOF_DOUBLE@
#cmakedefine SIZEOF_INT @SIZEOF_INT@
#cmakedefine SIZEOF_LONG @SIZEOF_LONG@
#cmakedefine SIZEOF_VOIDP @SIZEOF_VOIDP@
#cmakedefine STACK_DIRECTION @STACK_DIRECTION@
#cmakedefine STDC_HEADERS @STDC_HEADERS@
#cmakedefine TAGGED_LVALUE @TAGGED_LVALUE@
#cmakedefine TERMIOS_HAS_C_LINE @TERMIOS_HAS_C_LINE@
#cmakedefine TIME_WITH_SYS_TIME @TIME_WITH_SYS_TIME@
#cmakedefine UNION_WAIT @UNION_WAIT@
#cmakedefine USE_SIGINFO @USE_SIGINFO@
#cmakedefine USE_WINSOCK @USE_WINSOCK@2
#cmakedefine USE_XFT @USE_XFT@
#cmakedefine WIN32_GRAPHICS @WIN32_GRAPHICS@
#cmakedefine WORDS_BIGENDIAN @WORDS_BIGENDIAN@
#cmakedefine _REENTRANT @_REENTRANT@
#cmakedefine __CHAR_UNSIGNED__ @__CHAR_UNSIGNED__@

==> swipl-9.3.26.tar.gz: swipl-9.3.26/packages/xpce/config.h.cmake <==
#cmakedefine X11_GRAPHICS @X11_GRAPHICS@
#cmakedefine WIN32_GRAPHICS @WIN32_GRAPHICS@
#cmakedefine SDL_GRAPHICS @SDL_GRAPHICS@
#cmakedefine RAY_GRAPHICS @RAY_GRAPHICS@

#cmakedefine PCE_OS "@PCE_OS@"
#cmakedefine PCE_MACHINE "@PCE_MACHINE@"
#cmakedefine PCE_VERSION "@PCE_VERSION@"
#cmakedefine HAVE_ALLOCA @HAVE_ALLOCA@
#cmakedefine HAVE_ALLOCA_H @HAVE_ALLOCA_H@
#cmakedefine HAVE_ATEXIT @HAVE_ATEXIT@
#cmakedefine HAVE_BSTRING_H @HAVE_BSTRING_H@
#cmakedefine HAVE_CAST_VA_LIST @HAVE_CAST_VA_LIST@
#cmakedefine HAVE_CLOCK_GETTIME @HAVE_CLOCK_GETTIME@
#cmakedefine HAVE_CONIO_H @HAVE_CONIO_H@
#cmakedefine HAVE_CRT_EXTERNS_H @HAVE_CRT_EXTERNS_H@
#cmakedefine HAVE_DIRENT_H @HAVE_DIRENT_H@
#cmakedefine HAVE_FORK @HAVE_FORK@
#cmakedefine HAVE_FRAME_H @HAVE_FRAME_H@
#cmakedefine HAVE_FSTAT @HAVE_FSTAT@
#cmakedefine HAVE_FTIME @HAVE_FTIME@
#cmakedefine HAVE_GETCWD @HAVE_GETCWD@
#cmakedefine HAVE_GETDTABLESIZE @HAVE_GETDTABLESIZE@
#cmakedefine HAVE_GETHOSTNAME @HAVE_GETHOSTNAME@
#cmakedefine HAVE_GETLOGIN @HAVE_GETLOGIN@
#cmakedefine HAVE_GETPID @HAVE_GETPID@
#cmakedefine HAVE_GETPWNAM @HAVE_GETPWNAM@
#cmakedefine HAVE_GETTIMEOFDAY @HAVE_GETTIMEOFDAY@
#cmakedefine HAVE_GRANTPT @HAVE_GRANTPT@
#cmakedefine HAVE_INTTYPES_H @HAVE_INTTYPES_H@
#cmakedefine HAVE_JERROR_H @HAVE_JERROR_H@
#cmakedefine HAVE_LIBJPEG @HAVE_LIBJPEG@
#cmakedefine HAVE_LIBNSL @HAVE_LIBNSL@
#cmakedefine HAVE_LIBPTHREAD @HAVE_LIBPTHREAD@
#cmakedefine HAVE_LIBPTHREADGC @HAVE_LIBPTHREADGC@
#cmakedefine HAVE_LIBPTHREADGC @HAVE_LIBPTHREADGC@2
#cmakedefine HAVE_LIBSOCKET @HAVE_LIBSOCKET@
#cmakedefine HAVE_LIBXINERAMA @HAVE_LIBXINERAMA@
#cmakedefine HAVE_LIBXRANDR @HAVE_LIBXRANDR@
#cmakedefine HAVE_LIBXPM @HAVE_LIBXPM@
#cmakedefine HAVE_MALLOC_H @HAVE_MALLOC_H@
#cmakedefine HAVE_MEMMOVE @HAVE_MEMMOVE@
#cmakedefine HAVE_MEMORY_H @HAVE_MEMORY_H@
#cmakedefine HAVE_MKSTEMP @HAVE_MKSTEMP@
#cmakedefine HAVE_MKTIME @HAVE_MKTIME@
#cmakedefine HAVE_NANOSLEEP @HAVE_NANOSLEEP@
#cmakedefine HAVE_NDIR_H @HAVE_NDIR_H@
#cmakedefine HAVE_ON_EXIT @HAVE_ON_EXIT@
#cmakedefine HAVE_POSIX_OPENPT @HAVE_POSIX_OPENPT@
#cmakedefine HAVE_PIPE @HAVE_PIPE@
#cmakedefine HAVE_POLL @HAVE_POLL@
#cmakedefine HAVE_POLL_H @HAVE_POLL_H@
#cmakedefine HAVE_POPEN @HAVE_POPEN@
#cmakedefine HAVE_PWD_H @HAVE_PWD_H@
#cmakedefine HAVE_RENAME @HAVE_RENAME@
#cmakedefine HAVE_SCHED_H @HAVE_SCHED_H@
#cmakedefine HAVE_SCHED_YIELD @HAVE_SCHED_YIELD@
#cmakedefine HAVE_SELECT @HAVE_SELECT@
#cmakedefine HAVE_SETSID @HAVE_SETSID@
#cmakedefine HAVE_SHUTDOWN @HAVE_SHUTDOWN@
#cmakedefine HAVE_SIGACTION @HAVE_SIGACTION@
#cmakedefine HAVE_SIGINFO_H @HAVE_SIGINFO_H@
#cmakedefine HAVE_SOCKET @HAVE_SOCKET@
#cmakedefine HAVE_SOCKLEN_T @HAVE_SOCKLEN_T@
#cmakedefine HAVE_STDINT_H @HAVE_STDINT_H@
#cmakedefine HAVE_STDLIB_H @HAVE_STDLIB_H@
#cmakedefine HAVE_STPCPY @HAVE_STPCPY@
#cmakedefine HAVE_STRERROR @HAVE_STRERROR@
#cmakedefine HAVE_STRINGS_H @HAVE_STRINGS_H@
#cmakedefine HAVE_STRING_H @HAVE_STRING_H@
#cmakedefine HAVE_STROPTS_H @HAVE_STROPTS_H@
#cmakedefine HAVE_SYSINFO @HAVE_SYSINFO@
#cmakedefine HAVE_SYS_ACCESS_H @HAVE_SYS_ACCESS_H@
#cmakedefine HAVE_SYS_DIR_H @HAVE_SYS_DIR_H@
#cmakedefine HAVE_SYS_FILE_H @HAVE_SYS_FILE_H@
#cmakedefine HAVE_SYS_NDIR_H @HAVE_SYS_NDIR_H@
#cmakedefine HAVE_SYS_PARAM_H @HAVE_SYS_PARAM_H@
#cmakedefine HAVE_SYS_RESOURCE_H @HAVE_SYS_RESOURCE_H@
#cmakedefine HAVE_SYS_SELECT_H @HAVE_SYS_SELECT_H@
#cmakedefine HAVE_SYS_SOCKET_H @HAVE_SYS_SOCKET_H@
#cmakedefine HAVE_SYS_SOCKETVAR_H @HAVE_SYS_SOCKETVAR_H@
#cmakedefine HAVE_SYS_STAT_H @HAVE_SYS_STAT_H@
#cmakedefine HAVE_SYS_TIMEB_H @HAVE_SYS_TIMEB_H@
#cmakedefine HAVE_SYS_TIMES_H @HAVE_SYS_TIMES_H@
#cmakedefine HAVE_SYS_TIME_H @HAVE_SYS_TIME_H@
#cmakedefine HAVE_SYS_TYPES_H @HAVE_SYS_TYPES_H@
#cmakedefine HAVE_TEMPNAM @HAVE_TEMPNAM@
#cmakedefine HAVE_TERMIOS_H @HAVE_TERMIOS_H@
#cmakedefine HAVE_TERMIO_H @HAVE_TERMIO_H@
#cmakedefine HAVE_TIMEGM @HAVE_TIMEGM@
#cmakedefine HAVE_TIMELOCAL @HAVE_TIMELOCAL@
#cmakedefine HAVE_TMPNAM @HAVE_TMPNAM@
#cmakedefine HAVE_TM_GMTOFF @HAVE_TM_GMTOFF@
#cmakedefine HAVE_TTCOMPAT @HAVE_TTCOMPAT@
#cmakedefine HAVE_UNISTD_H @HAVE_UNISTD_H@
#cmakedefine HAVE_UXNT_H @HAVE_UXNT_H@
#cmakedefine HAVE_VISIBILITY_ATTRIBUTE @HAVE_VISIBILITY_ATTRIBUTE@
#cmakedefine HAVE_VSSCANF @HAVE_VSSCANF@
#cmakedefine HAVE_WINSOCK @HAVE_WINSOCK@
#cmakedefine HAVE_X11_EXTENSIONS_XINERAMA_H @HAVE_X11_EXTENSIONS_XINERAMA_H@
#cmakedefine HAVE_X11_EXTENSIONS_XRANDR_H @HAVE_X11_EXTENSIONS_XRANDR_H@
#cmakedefine HAVE_X11_XPM_H @HAVE_X11_XPM_H@
#cmakedefine HAVE_XFTNAMEUNPARSE @HAVE_XFTNAMEUNPARSE@
#cmakedefine HAVE_XINITTHREADS @HAVE_XINITTHREADS@
#cmakedefine HAVE_XMISMOTIFWMRUNNING @HAVE_XMISMOTIFWMRUNNING@
#cmakedefine HAVE_XTPOPUPSPRINGLOADED @HAVE_XTPOPUPSPRINGLOADED@
#cmakedefine HAVE__NSGETENVIRON @HAVE__NSGETENVIRON@
#cmakedefine O_DOSFILENAMES @O_DOSFILENAMES@
#cmakedefine O_HASSHARES @O_HASSHARES@
#cmakedefine O_PLMT @O_PLMT@
#cmakedefine O_XOS @O_XOS@
#cmakedefine PACKAGE_BUGREPORT @PACKAGE_BUGREPORT@
#cmakedefine PACKAGE_NAME @PACKAGE_NAME@
#cmakedefine PACKAGE_STRING @PACKAGE_STRING@
#cmakedefine PACKAGE_TARNAME @PACKAGE_TARNAME@
#cmakedefine PACKAGE_URL @PACKAGE_URL@
#cmakedefine PACKAGE_VERSION @PACKAGE_VERSION@
#cmakedefine POINTER_OFFSET @POINTER_OFFSET@
#cmakedefine RETSIGTYPE @RETSIGTYPE@
#cmakedefine SIZEOF_DOUBLE @SIZEOF_DOUBLE@
#cmakedefine SIZEOF_INT @SIZEOF_INT@
#cmakedefine SIZEOF_LONG @SIZEOF_LONG@
#cmakedefine SIZEOF_VOIDP @SIZEOF_VOIDP@
#cmakedefine SIZEOF_WCHAR_T @SIZEOF_WCHAR_T@
#cmakedefine STACK_DIRECTION @STACK_DIRECTION@
#cmakedefine STDC_HEADERS @STDC_HEADERS@
#cmakedefine TAGGED_LVALUE @TAGGED_LVALUE@
#cmakedefine TERMIOS_HAS_C_LINE @TERMIOS_HAS_C_LINE@
#cmakedefine TIME_WITH_SYS_TIME @TIME_WITH_SYS_TIME@
#cmakedefine UNION_WAIT @UNION_WAIT@
#cmakedefine USE_SIGINFO @USE_SIGINFO@
#cmakedefine USE_WINSOCK @USE_WINSOCK@2
#cmakedefine USE_XFT @USE_XFT@
#cmakedefine WORDS_BIGENDIAN @WORDS_BIGENDIAN@
#cmakedefine _REENTRANT @_REENTRANT@
#cmakedefine __CHAR_UNSIGNED__ @__CHAR_UNSIGNED__@
